==> Net-Amazon-0.06.tar.gz: Net-Amazon-0.06/lib/Net/Amazon/Request/Artist.pm <==
######################################################################
package Net::Amazon::Request::Artist;
######################################################################
use base qw(Net::Amazon::Request);

##################################################
sub new {
##################################################
    my($class, %options) = @_;

    if(exists $options{artist}) {
        $options{ArtistSearch} = $options{artist};
        delete $options{artist};
        $options{mode} = "music";
    } else {
        die "Mandatory parameter 'artist' not defined";
    }

    my $self = $class->SUPER::new(%options);

    bless $self, $class;   # reconsecrate
}

1;

__END__

=head1 NAME

Net::Amazon::Request::Artist - Class for submitting Artist requests

=head1 SYNOPSIS

  use Net::Amazon;
  use Net::Amazon::Request::Artist;

  my $ua = Net::Amazon->new(
      token       => 'YOUR_AMZN_TOKEN'
  );

  my $req = Net::Amazon::Request::Artist->new( 
      artist  => 'Zwan'
  );

    # Response is of type Net::Amazon::Response::Artist
  my $resp = $ua->request($req);

=head1 DESCRIPTION

C<Net::Amazon::Request::Artist> is a class used to submit Artist search
requests to the Amazon web service.

The artist to search for is specified in the C<artist> parameter.

Upon success, the responses' C<properties()> method will return a list of
C<Net::Amazon::Properties::Music> objects.

Check L<Net::Amazon::Request> for common request parameters not listed here.

=head2 METHODS

=over 4

=item new( artist => $artist )

Constructs a new C<Net::Amazon::Request::Artist> object, used to query
the Amazon web service for items of a given artist.

=back

=head1 SEE ALSO

=head1 AUTHOR

Mike Schilli, E<lt>m@perlmeister.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2003 by Mike Schilli E<lt>m@perlmeister.comE<gt>

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself. 

=cut

==> Net-Amazon-0.30.tar.gz: Net-Amazon-0.30/lib/Net/Amazon/Request/Artist.pm <==
######################################################################
package Net::Amazon::Request::Artist;
######################################################################
use warnings;
use strict;
use base qw(Net::Amazon::Request);

##################################################
sub new {
##################################################
    my($class, %options) = @_;

    if(exists $options{artist}) {
        $options{ArtistSearch} = $options{artist};
        delete $options{artist};
        $options{mode} = "music";
    } else {
        die "Mandatory parameter 'artist' not defined";
    }

    my $self = $class->SUPER::new(%options);

    bless $self, $class;   # reconsecrate
}

1;

__END__

=head1 NAME

Net::Amazon::Request::Artist - Class for submitting Artist requests

=head1 SYNOPSIS

  use Net::Amazon;
  use Net::Amazon::Request::Artist;

  my $ua = Net::Amazon->new(
      token       => 'YOUR_AMZN_TOKEN'
  );

  my $req = Net::Amazon::Request::Artist->new( 
      artist  => 'Zwan'
  );

    # Response is of type Net::Amazon::Response::Artist
  my $resp = $ua->request($req);

=head1 DESCRIPTION

C<Net::Amazon::Request::Artist> is a class used to submit Artist search
requests to the Amazon web service.

The artist to search for is specified in the C<artist> parameter.

Upon success, the responses' C<properties()> method will return a list of
C<Net::Amazon::Property::Music> objects.

Check L<Net::Amazon::Request> for common request parameters not listed here.

=head2 METHODS

=over 4

=item new( artist => $artist )

Constructs a new C<Net::Amazon::Request::Artist> object, used to query
the Amazon web service for items of a given artist.

=back

=head1 SEE ALSO

=head1 AUTHOR

Mike Schilli, E<lt>m@perlmeister.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2003 by Mike Schilli E<lt>m@perlmeister.comE<gt>

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself. 

=cut
